package com.persagy.apm.common.config;

import com.persagy.apm.common.exception.RpcException;
import com.persagy.apm.common.response.*;
import com.persagy.common.enums.ResponseCode;
import lombok.extern.slf4j.Slf4j;
import org.aspectj.lang.annotation.AfterReturning;
import org.aspectj.lang.annotation.Aspect;
import org.aspectj.lang.annotation.Pointcut;

/**
 * feign调用poems接口，如果接口返回了报错信息，将报错信息抛出
 *
 * @author lixing
 * @version V1.0 2021/3/24 4:55 下午
 **/
@Aspect
@Slf4j
public class PoemsFeignExceptionHandler {

    @Pointcut("@within(org.springframework.cloud.openfeign.FeignClient)")
    private void pointCutMethod() {
    }

    @AfterReturning(pointcut = "pointCutMethod()", returning = "res")
    public void process(Object res) {
        log.info("feign调用接口，返回结果：{}", res);
        String result = null;
        String reason = null;
        if (res instanceof PoemsFeignResponse) {
            PoemsFeignResponse response = (PoemsFeignResponse) res;
            result = response.getResult();
            reason = response.getReason();
        }

        if (res instanceof DmpPageResponse) {
            DmpPageResponse response = (DmpPageResponse) res;
            result = response.getResult();
            reason = response.getMessage();
        }

        String success = "success";
        if (!success.equals(result)) {
            throw new RpcException(reason);
        }
    }
}
